@@ -6,7 +6,7 @@ BEGIN {
   $Gentoo::Overlay::Category::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Gentoo::Overlay::Category::VERSION = '1.0.4';
+  $Gentoo::Overlay::Category::VERSION = '1.0.5';
 }
 
 # ABSTRACT: A singular category in a repository;
@@ -59,13 +59,14 @@ sub _build__packages {
   my $it = $self->path->iterator();
   my %out;
   while ( defined( my $entry = $it->() ) ) {
-    next if Gentoo::Overlay::Package->is_blacklisted( $entry->basename );
+    my $package = $entry->basename;
+    next if Gentoo::Overlay::Package->is_blacklisted($package);
     my $p = Gentoo::Overlay::Package->new(
-      name     => $entry->basename,
+      name     => $package,
       category => $self,
     );
     next unless $p->exists;
-    $out{$entry} = $p;
+    $out{$package} = $p;
   }
   return \%out;
 }
@@ -180,7 +181,7 @@ Gentoo::Overlay::Category - A singular category in a repository;
 
 =head1 VERSION
 
-version 1.0.4
+version 1.0.5
 
 =head1 SYNOPSIS
 
